builders/installer_builder library
This file contains the InstallerBuilder class, which is responsible for creating the installer for the application using Inno Setup.
The InstallerBuilder class builds the installer based on the provided configuration and script file, using the Config.innoExec path for the ISCC executable. It also supports signing the installer if a SignTool is configured.
Classes
- InstallerBuilder
- A class responsible for building the installer using Inno Setup.