InnoBundleCliConfig constructor

const InnoBundleCliConfig({
  1. BuildType type = BuildType.release,
  2. bool app = true,
  3. bool installer = true,
  4. String? buildArgs,
  5. String? appVersion,
  6. String? signToolName,
  7. String? signToolCommand,
  8. String? signToolParams,
  9. bool installInnoSetup = true,
  10. bool generateAppId = true,
  11. bool generatePublisher = true,
  12. String? appIdNamespace,
  13. String? path,
  14. bool envs = false,
  15. bool hf = true,
  16. bool help = false,
  17. bool listLanguages = false,
})

Creates an instance with the given values.

Every option defaults to the same behaviour as invoking the command with no arguments, so a bare InnoBundleCliArgs() is a valid default config.

Implementation

const InnoBundleCliConfig({
  this.type = BuildType.release,
  this.app = true,
  this.installer = true,
  this.buildArgs,
  this.appVersion,
  this.signToolName,
  this.signToolCommand,
  this.signToolParams,
  this.installInnoSetup = true,
  this.generateAppId = true,
  this.generatePublisher = true,
  this.appIdNamespace,
  this.path,
  this.envs = false,
  this.hf = true,
  this.help = false,
  this.listLanguages = false,
});