envs property
Whether to print the resolved configuration as environment variables and exit before doing any build work.
Implementation
final bool envs;
Whether to print the resolved configuration as environment variables and exit before doing any build work.
final bool envs;