generateAppId property
Whether to generate an App ID and persist it into the config file.
Only takes effect when the config file has no id yet.
Implementation
final bool generateAppId;
Whether to generate an App ID and persist it into the config file.
Only takes effect when the config file has no id yet.
final bool generateAppId;