generatePublisher property

bool generatePublisher
final

Whether to derive a publisher name and persist it into the config file.

Falls back to the logged-in username, and only if neither the config file nor the maintainer field provides a publisher.

Implementation

final bool generatePublisher;