installInnoSetup property

bool installInnoSetup
final

Whether to make sure Inno Setup is installed before building.

Downloads and extracts the default Inno Setup version under ~/.inno_bundle/versions via InnoVersionManager when no Inno Setup install is detected. The install is skipped if one is already present (managed or system-wide).

Implementation

final bool installInnoSetup;