parser property

ArgParser parser
getter/setter pair

Declares the command-line options accepted by the command.

The help: strings are shown verbatim to users through --help.

Implementation

static ArgParser parser = ArgParser()
  ..addFlag(BuildType.release.name, negatable: false, help: 'Default flag')
  ..addFlag(BuildType.profile.name, negatable: false)
  ..addFlag(BuildType.debug.name, negatable: false)
  ..addFlag('app', defaultsTo: true, help: 'Build app')
  ..addFlag('installer', defaultsTo: true, help: 'Build installer')
  ..addFlag(
    'install-inno',
    defaultsTo: true,
    help: 'Install Inno Setup under ~/.inno_bundle/versions if not '
        'already installed',
  )
  ..addFlag(
    'gen-app-id',
    defaultsTo: true,
    help: 'Generate a random App ID into your config file if non-existent\n'
        'This will use namespace from --app-id-ns if provided',
  )
  ..addOption(
    'path',
    help: 'Path to custom config file. Default: pubspec.yaml',
  )
  ..addOption(
    "app-id-ns",
    help: "Namespace for --gen-app-id\nExample: www.example.com",
  )
  ..addFlag(
    'gen-publisher',
    defaultsTo: true,
    help: 'Generate a publisher name into config file if non-existent\n'
        'This will generate based on username of logged in user in machine\n'
        'and only if maintainer field is not present in config file',
  )
  ..addOption("build-args", help: "Append args to \"flutter build ...\"")
  ..addOption("app-version", help: "Override app version")
  ..addOption("sign-tool-name", help: "Override sign tool name")
  ..addOption("sign-tool-command", help: "Override sign tool command")
  ..addOption("sign-tool-params", help: "Override sign tool params")
  ..addFlag(
    'envs',
    defaultsTo: false,
    negatable: false,
    help: "Print env variables and exit",
  )
  ..addFlag('hf', defaultsTo: true, help: 'Print header and footer')
  ..addFlag('list-languages',
      negatable: false, help: 'List all supported languages and exit')
  ..addFlag('help', abbr: 'h', negatable: false, help: 'Print help and exit');