Config class
A class representing the configuration for building a Windows installer using Inno Setup.
Constructors
-
Config({required File pubspecFile, required File configFile, required List<
FileEntry> files, required List<String> includedFileExts, required List<String> excludedFileExts, required String? buildArgs, required String id, required String pubspecName, required String name, required String description, required String version, required String publisher, required String url, required String supportUrl, required String updatesUrl, required String installerIcon, required List<Language> languages, required AdminMode admin, required String licenseFile, required SignTool? signTool, required BuildArch arch, required VcRedistMode vcRedist, required File innoExec, required Directory baseDir, BuildType type = BuildType.release, bool app = true, bool installer = true, List<String> outputDir = installerBuildDir}) - Creates a Config instance with default values.
-
Config.fromFile(File pubspecFile, File configFile, File innoExec, InnoBundleCliConfig cliConfig, {List<
String> outputDir = installerBuildDir, Directory? baseDir}) -
Creates a Config instance directly from the
pubspec.yamlfile and a config file (if provided).factory -
Config.fromJson(Map<
String, dynamic> json, Map<String, dynamic> configJson, {required File pubspecFile, required File configFile, required File innoExec, required InnoBundleCliConfig cliConfig, List<String> outputDir = installerBuildDir, Directory? baseDir}) -
Creates a Config instance from a JSON map, typically read from
pubspec.yamland a config file (if provided).factory
Properties
- admin → AdminMode
-
Whether the installer requires administrator privileges.
final
- app → bool
-
Whether to include the app in the installer.
final
- arch → BuildArch
-
CPU Architecture supported by the app and installer to run on.
final
- baseDir → Directory
-
The base directory relative paths in the config are resolved against.
final
- buildArgs → String?
-
Arguments to be passed to flutter build.
final
- configFile → File
-
The config file sourced for this configuration, used as the main source of values.
final
- description → String
-
A description of the app being packaged.
final
-
excludedFileExts
→ List<
String> -
List of file extensions to remove in case they were added in includedFileExts before.
final
-
files
→ List<
FileEntry> -
List of files to be included in the installer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier (UUID) for the app being packaged.
final
-
includedFileExts
→ List<
String> -
List of file extensions to assign for/associate with the app (ie. "Open with" in file explorer menu).
final
- innoExec → File
-
The resolved ISCC.exe executable used to build the installer.
final
- installer → bool
-
Whether to create an installer file.
final
- installerIcon → String
-
The path to the installer icon file.
final
-
languages
→ List<
Language> -
The supported languages for the installer.
final
- licenseFile → String
-
The path to the text license file.
final
- name → String
-
The name of the app after packaging.
final
-
outputDir
→ List<
String> -
Relative path segments for the installer output directory.
final
- publisher → String
-
The name of the publisher or maintainer.
final
- pubspecFile → File
-
The pubspec file sourced for this configuration, used as a fallback source of values.
final
- pubspecName → String
-
The global pubspec name attribute, same name of the exe generated from flutter build.
final
- pubspecNameDotExe → String
-
The name of the executable file that is created with flutter build.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signTool → SignTool?
-
The name or commmand to be used to digitally sign the installer.
final
- supportUrl → String
-
The URL for support resources.
final
- type → BuildType
-
The build type (release, profile, or debug).
final
- updatesUrl → String
-
The URL for checking for updates.
final
- url → String
-
The app's homepage URL.
final
- vcRedist → VcRedistMode
-
The mode for handling the Visual C++ Redistributable.
final
- version → String
-
The app's version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEnvironmentVariables(
) → String - Returns a string containing the config attributes as environment variables.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolveConfigFile(
{required String? configPath, required File pubspecFile, required File defaultConfigFile}) → File - Resolves which file the command should read its config from.