excludedFileExts property

List<String> excludedFileExts
final

List of file extensions to remove in case they were added in includedFileExts before.

Normally, the file associations will get removed on app uninstall, but this can be used to dynamically remove them with a normal update.

Implementation

final List<String> excludedFileExts;