pubspecNameDotExe property
String
get
pubspecNameDotExe
The name of the executable file that is created with flutter build.
Implementation
String get pubspecNameDotExe => "$pubspecName.exe";
The name of the executable file that is created with flutter build.
String get pubspecNameDotExe => "$pubspecName.exe";