utils/constants library

Contains various constants and utility values used throughout the Inno Bundle package.

This file includes:

  • Messages displayed in the CLI during different stages of the build process.
  • Paths for directories and files used during the build and installation process.
  • Globally used regular expressions.

Constants

appBuildDir → const List<String>
Relative build directory path for x64 windows app.
BUILD_END_MESSAGE → const String
End message for the CLI
defaultConfigFileName → const String
Default name of the package's own config file.
defaultInstallerIconPlaceholder → const String
Placeholder used by inno_bundle to signify that the default installer icon should be used.
GUID_END_MESSAGE → const String
End message for the CLI
installerBuildDir → const List<String>
Relative output directory path for x64 windows installer.
pubspecFileName → const String
Default name of the Flutter project manifest.
scriptHeader → const String
Header message for ISS script
SETUP_VERSIONS_END_MESSAGE → const String
End message for the CLI's setup_versions command
START_MESSAGE → const String
Start message for the CLI
system32 → const List<String>
System32 directory path for MS Windows.
vcDllFiles → const List<String>
List of DLL files that must be included to avoid missing dll files issue for users. See https://github.com/hahouari/inno_bundle/wiki/Handling-Missing-DLL-Files.

Properties

validFilenameRegex RegExp
Regex for filenames and directories. used to make sure some generated files do not have special characters in the names.
final