IdCliConfig class
The fully resolved CLI options for the id command.
Constructors
- IdCliConfig({required String? ns, required bool hf, required bool help})
- Creates an instance with the given values.
-
IdCliConfig.parse(List<
String> arguments) -
Parses the given
argumentsinto an IdCliConfig.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → bool
-
Whether to print usage and exit without outputting an ID.
final
- hf → bool
-
Whether to print the header/footer lines framing the output.
final
- ns → String?
-
Namespace to generate a namespaced (UUIDv5) App ID from.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
helpMessage(
) → String - Returns the usage message describing the accepted options.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- parser ↔ ArgParser
-
Declares the options accepted by the
idcommand.getter/setter pair