app property
Whether to build the app itself.
When false the installer is produced from an already-built app instead of triggering a new Flutter build.
Implementation
final bool app;
Whether to build the app itself.
When false the installer is produced from an already-built app instead of triggering a new Flutter build.
final bool app;