Language class
A language supported by the Inno Setup installer.
Properties
- file → String
-
The filename of the language-specific Inno Setup language file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innoEntry → String
-
Generates the Inno Setup language item for this language.
no setter
- name → String
-
The name of the language, derived from the filename, or English for Default.isl.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
getByNameOrNull(
String name) → Language? -
Retrieves a Language instance by its name, or
nullif not found. -
listLanguages(
) → Never -
Prints all supported language names separated by
,and exits. -
loadLanguages(
String innoPath) → void - Loads the supported languages for the given Inno Setup executable path.
-
validateConfig(
dynamic option, {required String configName}) → String? - Validate configuration option for Language.